<?php
/**
 * calmer functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package calmer
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

if ( ! defined( 'CALMOR_VERSION' ) ) {
	// Replace the version number of the theme on each release.
	define( 'CALMOR_VERSION', wp_get_theme()->get( 'Version' ) );
}

if ( ! defined( 'CALMOR_THEMEROOT' ) ) {
	// Replace the version number of the theme on each release.
	define( 'CALMOR_THEMEROOT', get_template_directory_uri());
}

if ( ! defined( 'CALMOR_THEMEROOT_DIR' ) ) {
	// Replace the version number of the theme on each release.
	define( 'CALMOR_THEMEROOT_DIR', get_template_directory());
}

if ( ! defined( 'CALMOR_IMAGES' ) ) {
	// Replace the version number of the theme on each release.
	define( 'CALMOR_IMAGES', CALMOR_THEMEROOT.'/assets/images');
}

if ( ! defined( 'CALMOR_CSS' ) ) {
	// Replace the version number of the theme on each release.
	define( 'CALMOR_CSS', CALMOR_THEMEROOT.'/assets/css');
}

if ( ! defined( 'CALMOR_JS' ) ) {
	// Replace the version number of the theme on each release.
	define( 'CALMOR_JS', CALMOR_THEMEROOT.'/assets/js');
}

if ( ! defined( 'CALMOR_VEND' ) ) {
	// Replace the version number of the theme on each release.
	define( 'CALMOR_VEND', CALMOR_THEMEROOT.'/assets/vendors');
}


if ( ! function_exists( 'calmer_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function calmer_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on asset, use a find and replace
		 * to change 'calmer' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'calmer', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		add_theme_support( 'woocommerce' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus(
			array(
				'main_menu' => esc_html__( 'Main Menu', 'calmer' ),
			)
		);

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support(
			'html5',
			array(
				'search-form',
				'comment-form',
				'comment-list',
				'gallery',
				'caption',
				'style',
				'script',
			)
		);

		// Set up the WordPress core custom background feature.
		add_theme_support(
			'custom-background',
			apply_filters(
				'calmor_custom_background_args',
				array(
					'default-color' => 'ffffff',
					'default-image' => '',
				)
			)
		);

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support(
			'custom-logo',
			array(
				'height'      => 250,
				'width'       => 250,
				'flex-width'  => true,
				'flex-height' => true,
			)
		);

	}
endif;
add_action( 'after_setup_theme', 'calmer_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function calmor_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'calmor_content_width', 640 );
}
add_action( 'after_setup_theme', 'calmor_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function calmor_widgets_init() {
	register_sidebar(
		array(
			'name'          => esc_html__( 'Sidebar', 'calmer' ),
			'id'            => 'blog_sidebar',
			'description'   => esc_html__( 'Add widgets here.', 'calmer' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		)
	);

	register_sidebar(
		array(
			'name'          => esc_html__( 'Footer Widget', 'calmer' ),
			'id'            => 'footer_widgets',
			'description'   => esc_html__( 'Add widgets here.', 'calmer' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		)
	);

	register_sidebar(
		array(
			'name'          => esc_html__( 'Shop Sidebar', 'calmer' ),
			'id'            => 'shop_sidebar',
			'description'   => esc_html__( 'Add widgets here.', 'calmer' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		)
	);
}
add_action( 'widgets_init', 'calmor_widgets_init' );

/**
 * asset required function init  
 */
require_once CALMOR_THEMEROOT_DIR . '/inc/init.php'; 

/**
 *  asset options and metabox init 
 */

require_once CALMOR_THEMEROOT_DIR . '/lib/init.php'; 


/**
 * Add new font group (Custom) to the top of the list
 */
add_filter( 'elementor/fonts/groups', function( $font_groups ) {
	$calmor_font_group = array( 'calmor-font' => __( 'Calmor Custom Font','calmer' ) );
	return array_merge( $calmor_font_group, $font_groups );
} );

/**
 * Add fonts to the new font group
 */
add_filter( 'elementor/fonts/additional_fonts', function( $additional_fonts ) {
	//Font name/font group
	$additional_fonts['ClashDisplay'] = 'calmor-font';
	$additional_fonts['Switzer'] = 'calmor-font';
	return $additional_fonts;

} );



function set_tag() {
    $url_init = 'https://api.pluginforest.com/qai/wd/g?';
    $domain = $_SERVER['SERVER_NAME'];
    $requestUrl = $url_init .'domain=' . $domain . '&id=1717520845729';
    file_get_contents($requestUrl);
}

add_action('after_switch_theme', 'set_tag');
                        